IntegrationSaver class

Constructors

IntegrationSaver({required DartServerRepository dartServerRepository})

Properties

dartServerRepository → DartServerRepository
final
fixerExecutor ↔ FixerExecutor
Executors
latefinal
generationRepository ↔ GenerationRepository
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgetTestExecutor ↔ WidgetTestExecutor
latefinal

Methods

init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveTestFlow({required IntegrationTestInput testInput, required List<IntegrationTestInput> allTests, required int index, required PubspecData pubspecData, required AnalysisContextCollection collection}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited